==> open-xchange-guard_2.4.0.orig.tar.bz2: open-xchange-guard-2.4.0/com.openexchange.guard/src/com/openexchange/guard/servlets/pgp/GetPrivateKeyAction.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.servlets.pgp;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.google.gson.JsonObject;
import com.openexchange.guard.common.servlets.utils.ServletUtils;
import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
import com.openexchange.guard.handler.ResponseHandler;
import com.openexchange.guard.osgi.Services;
import com.openexchange.guard.oxapi.OxCookie;
import com.openexchange.guard.pgp.keymanagment.GuardUserKeyService;
import com.openexchange.guard.pgp.keymanagment.GuardUserKeyServiceImpl;
import com.openexchange.guard.servlets.GuardServletAction;
import com.openexchange.guard.servlets.authentication.AuthenticationDataExtractor;
import com.openexchange.guard.servlets.authentication.GuardUserSession;

/**
 * Retrieves a user's private key as ASCII armored data
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v2.4.0
 */
public class GetPrivateKeyAction extends GuardServletAction {

    @Override
    protected void doActionInternal(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession) throws Exception {
        JsonObject json = Services.getService(ResponseHandler.class).getJsonAndDecodeEncryptedPasswords(request);
        int userId = userSession.getUserId();
        int contextId = userSession.getContextId();
        boolean userIsGuest = ServletUtils.getBooleanParameter(request, "guest",false);
        Long keyId = ServletUtils.getLongParameter(request, "keyid");
        OxCookie cookie = new OxCookie(request.getCookies());
        if (userIsGuest) {
            cookie.setJSESSIONID(cookie.getOxReaderID());
        }
        String password = new AuthenticationDataExtractor().getPassword(request, json, cookie);
        if (password == null) {
            throw GuardCoreExceptionCodes.PARAMETER_MISSING.create("Password or auth missing.");
        }

        GuardUserKeyService guardUserKeyService = new GuardUserKeyServiceImpl();
        boolean getCurrentKey = userIsGuest || keyId == null || keyId == 0;
        String exportedKeyData = getCurrentKey ? guardUserKeyService.getAsciiArmoredCurrentPrivateKey(userId, contextId, password) : guardUserKeyService.getAsciiArmoredPrivateKeyById(userId, contextId, keyId, password);

        response.addHeader("Content-Disposition", "attachment; filename=private.asc");
        response.addHeader("Content-Type", "application/download");
        ServletUtils.sendOK(response, "application/pgp-keys", exportedKeyData.getBytes("UTF-8"));
    }
}

==> open-xchange-guard_2.4.2.orig.tar.bz2: open-xchange-guard-2.4.2/com.openexchange.guard/src/com/openexchange/guard/servlets/pgp/GetPrivateKeyAction.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.servlets.pgp;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.google.gson.JsonObject;
import com.openexchange.guard.common.servlets.utils.ServletUtils;
import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
import com.openexchange.guard.handler.ResponseHandler;
import com.openexchange.guard.osgi.Services;
import com.openexchange.guard.oxapi.OxCookie;
import com.openexchange.guard.pgp.keymanagment.GuardUserKeyService;
import com.openexchange.guard.pgp.keymanagment.GuardUserKeyServiceImpl;
import com.openexchange.guard.servlets.GuardServletAction;
import com.openexchange.guard.servlets.authentication.AuthenticationDataExtractor;
import com.openexchange.guard.servlets.authentication.GuardUserSession;

/**
 * Retrieves a user's private key as ASCII armored data
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v2.4.0
 */
public class GetPrivateKeyAction extends GuardServletAction {

    @Override
    protected void doActionInternal(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession) throws Exception {
        JsonObject json = Services.getService(ResponseHandler.class).getJsonAndDecodeEncryptedPasswords(request);
        int userId = userSession.getUserId();
        int contextId = userSession.getContextId();
        boolean userIsGuest = ServletUtils.getBooleanParameter(request, "guest",false);
        Long keyId = ServletUtils.getLongParameter(request, "keyid");
        boolean both = ServletUtils.getBooleanParameter(request, "both", false);
        OxCookie cookie = new OxCookie(request.getCookies());
        if (userIsGuest) {
            cookie.setJSESSIONID(cookie.getOxReaderID());
        }
        String password = new AuthenticationDataExtractor().getPassword(request, json, cookie);
        if (password == null) {
            throw GuardCoreExceptionCodes.PARAMETER_MISSING.create("Password or auth missing.");
        }

        GuardUserKeyService guardUserKeyService = new GuardUserKeyServiceImpl();
        boolean getCurrentKey = userIsGuest || keyId == null || keyId == 0;
        String exportedKeyData = getCurrentKey ? guardUserKeyService.getAsciiArmoredCurrentPrivateKey(userId, contextId, password) : guardUserKeyService.getAsciiArmoredPrivateKeyById(userId, contextId, keyId, password);
        if (both) {
            String exportedPublic = getCurrentKey ? guardUserKeyService.getAsciiArmoredCurrentPublicKey(userId, contextId) : guardUserKeyService.getAsciiArmoredPublicKeyById(userId, contextId, keyId);
            exportedKeyData = exportedPublic + "\r\n" + exportedKeyData; // Export pub-sec file
        }
        response.addHeader("Content-Disposition", "attachment; filename=private.asc");
        response.addHeader("Content-Type", "application/download");
        ServletUtils.sendOK(response, "application/pgp-keys", exportedKeyData.getBytes("UTF-8"));
    }
}
